==> openflowplugin-extension-nicira-0.8.3-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/NxActionMultipathGrouping.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714;
import org.eclipse.jdt.annotation.NonNull;
import org.eclipse.jdt.annotation.Nullable;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.nx.action.multipath.grouping.NxMultipath;
import org.opendaylight.yangtools.yang.binding.DataObject;
import org.opendaylight.yangtools.yang.common.QName;

/**
 *
 * <p>
 * This class represents the following YANG schema fragment defined in module <b>openflowplugin-extension-nicira-action</b>
 * <pre>
 * grouping nx-action-multipath-grouping {
 *   container nx-multipath {
 *     leaf fields {
 *       type nicira-action:ofj-nx-hash-fields;
 *     }
 *     leaf basis {
 *       type uint16;
 *       default 0x400;
 *     }
 *     leaf algorithm {
 *       type nicira-action:ofj-nx-mp-algorithm;
 *     }
 *     leaf max-link {
 *       type uint16;
 *     }
 *     leaf arg {
 *       type uint32;
 *     }
 *     container dst {
 *       uses dst-choice-grouping;
 *       uses range-grouping;
 *     }
 *   }
 * }
 * </pre>The schema path to identify an instance is
 * <i>openflowplugin-extension-nicira-action/nx-action-multipath-grouping</i>
 *
 */
public interface NxActionMultipathGrouping
    extends
    DataObject
{



    public static final @NonNull QName QNAME = $YangModuleInfoImpl.qnameOf("nx-action-multipath-grouping");

    /**
     * @return <code>org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.nx.action.multipath.grouping.NxMultipath</code> <code>nxMultipath</code>, or <code>null</code> if not present
     */
    @Nullable NxMultipath getNxMultipath();

}

==> openflowplugin-extension-nicira-0.9.3-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/NxActionMultipathGrouping.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714;
import java.lang.Class;
import java.lang.Override;
import org.eclipse.jdt.annotation.NonNull;
import org.eclipse.jdt.annotation.Nullable;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.nx.action.multipath.grouping.NxMultipath;
import org.opendaylight.yangtools.yang.binding.DataObject;
import org.opendaylight.yangtools.yang.common.QName;

/**
 *
 * <p>
 * This class represents the following YANG schema fragment defined in module <b>openflowplugin-extension-nicira-action</b>
 * <pre>
 * grouping nx-action-multipath-grouping {
 *   container nx-multipath {
 *     leaf fields {
 *       type nicira-action:ofj-nx-hash-fields;
 *     }
 *     leaf basis {
 *       type uint16;
 *       default 0x400;
 *     }
 *     leaf algorithm {
 *       type nicira-action:ofj-nx-mp-algorithm;
 *     }
 *     leaf max-link {
 *       type uint16;
 *     }
 *     leaf arg {
 *       type uint32;
 *     }
 *     container dst {
 *       uses dst-choice-grouping;
 *       uses range-grouping;
 *     }
 *   }
 * }
 * </pre>The schema path to identify an instance is
 * <i>openflowplugin-extension-nicira-action/nx-action-multipath-grouping</i>
 *
 */
public interface NxActionMultipathGrouping
    extends
    DataObject
{



    public static final @NonNull QName QNAME = $YangModuleInfoImpl.qnameOf("nx-action-multipath-grouping");

    @Override
    Class<? extends NxActionMultipathGrouping> implementedInterface();
    
    /**
     * @return <code>org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.nx.action.multipath.grouping.NxMultipath</code> <code>nxMultipath</code>, or <code>null</code> if not present
     */
    @Nullable NxMultipath getNxMultipath();

}
